/* attempting to fix AA's wrong usage of bootstrap classes
------------------------------------------------------------------------------------- */
@media all {
  .aa-inactivity {
    margin-left: 15px;
  }
}

@media all and (min-width: 768px) {
  .aa-inactivity {
    margin-left: 0;
  }
}
